const OFF   = 0;    // OFF   or 0 - turn the rule off
const WARN  = 1;    // WARN  or 1 - turn the rule on as a warning (does not affect exit code)
const ERROR = 2;    // ERROR or 2 - turn the rule on as an error (exit code will be 1)


module.exports = {
  extends: './index.js',
  root: true,
  rules: {
    'import/no-unused-modules': OFF,    // importing rules
    'import/unambiguous': OFF,          // source is 'modules'
    'no-unused-vars': OFF,              // for documenting & consistency
    'no-use-before-define': OFF,        // keeping file consistency
    'id-length': OFF                    // eslint identifiers are long!
  }
};


// https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/order.md
/**
 *  1. node "builtin" modules
    import fs from 'fs';
    import path from 'path';
    2. "external" modules
    import _ from 'lodash';
    import chalk from 'chalk';
    3. "internal" modules
    (if you have configured your path or webpack to handle your internal paths differently)
    import foo from 'src/foo';
    import Notifications from 'Shared/Notifications';
    import Bookmark from 'Components/Bookmark';
    4. modules from a "parent" directory
    import foo from '../foo';
    import qux from '../../foo/qux';
    5. "sibling" modules from the same or a sibling's directory
    import bar from './bar';
    import baz from './bar/baz';
    6. "index" of the current directory
    import main from './';
    7. "object"-imports (only available in TypeScript)
    import log = console.log;
    8. "type" imports (only available in Flow and TypeScript)
    import type { Foo } from 'foo';
 */

// --EXAMPLE--
// import fs from 'fs';
// import path from 'path';
// import React from 'react';
// import { bool, object } from 'prop-types';
// import Spinner from 'Shared/Spinner';
// import Annotation from 'Components/Annotation';
// import CSS from './styles.css';
// import bar from './bar';
// import icons from './icons';
// import main from './';
// import type { Foo } from 'foo';;


// / add rule to order import statements based on file type &&|| folder/file names alphabetically
//
// --EXAMPLE--
// import React from 'react';
// import { bool, object } from 'prop-types';
// import CSS from './styles.css';

// import Spinner from 'Shared/Spinner';
// import Notifications from 'Shared/Notifications';
// import Bookmark from 'Components/Bookmark';
// import RightSidePanel from 'Components/RightSidePanel';
// import Annotation from 'Components/Annotation';
// import FAB from 'Components/FAB';
// import Navigation from 'Components/Navigation';
// import VSReader from 'Components/VSReader';
//
// --RESULTS --
// import React from 'react';
// import { bool, object } from 'prop-types';
// <SPACED-added>
// import Annotation from 'Components/Annotation';
// import Bookmark from 'Components/Bookmark';
// import FAB from 'Components/FAB';
// import Navigation from 'Components/Navigation';
// import RightSidePanel from 'Components/RightSidePanel';
// import VSReader from 'Components/VSReader';
// import Notifications from 'Shared/Notifications';
// import Spinner from 'Shared/Spinner';
// <SPACED-added>
// import CSS from './styles.css';

// add rule to distinguish between 'node_module' import vs 'src' import
//
// --EXAMPLE--
// import React, { Component } from 'react';
// import { string, func, bool } from 'prop-types';
// import { connect } from 'react-redux';
// import { goToPage, notifications, SET_PAGE_BREAK_ERROR } from 'PipeRouter';
// import PageSelectorViews from './views';
//
// --RESULTS --
// import React, { Component } from 'react';
// import { string, func, bool } from 'prop-types';
// import { connect } from 'react-redux';
// <SPACE-added>
// import { goToPage, notifications, SET_PAGE_BREAK_ERROR } from 'PipeRouter';
// import PageSelectorViews from './views';
// <SPACE-added>


// add rule to add space better imported libraries & code constructs
//
// --EXAMPLE--
// import { goToPage, notifications, SET_PAGE_BREAK_ERROR } from 'PipeRouter';
// import PageSelectorViews from './views';
// import { goToPage, notifications, SET_PAGE_BREAK_ERROR } from 'PipeRouter';
// import PageSelectorViews from './views';
// class PageSelector extends Component { ...
//
// --RESULTS --
// import { goToPage, notifications, SET_PAGE_BREAK_ERROR } from 'PipeRouter';
// import PageSelectorViews from './views';
// import { goToPage, notifications, SET_PAGE_BREAK_ERROR } from 'PipeRouter';
// import PageSelectorViews from './views';
// <SPACE-added>
// <SPACE-added>
// class PageSelector extends Component { ...


// add rule to add space above/below 'export' statements
//
// --EXAMPLE--
// function mapStateToProps(state) {}
// module.exports = connect(mapStateToProps, { goToPage, notifications })(PageSelector);
//
// --RESULTS --
// function mapStateToProps(state) {}
// <SPACE-added>
// <SPACE-added>
// module.exports = connect(mapStateToProps, { goToPage, notifications })(PageSelector);

// -----------------------------
