const OFF   = 0;    // OFF   or 0 - turn the rule off
const WARN  = 1;    // WARN  or 1 - turn the rule on as a warning (does not affect exit code)
const ERROR = 2;    // ERROR or 2 - turn the rule on as an error (exit code will be 1)


module.exports = {
  parserOptions: {
    ecmaVersion: '2022',
    sourceType: 'module'
  },
  plugins: [
    'promise'
  ],
  rules: {
    // enforce the use of `catch()` on un-returned promises
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/catch-or-return.md
    'promise/catch-or-return': [ERROR, {
      allowThen: true,
      allowFinally: true
    }],

    // disallow wrapping values in `Promise.resolve` or `Promise.reject` when not needed
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/no-return-wrap.md
    'promise/no-return-wrap': ERROR,

    // enforce consistent param names and ordering when creating new promises
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/param-names.md
    'promise/param-names': ERROR,

    // enforce inside each `then()` to create readable and reusable Promise chains
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/always-return.md
    'promise/always-return': ERROR,

    // enforce to create a `Promise` constructor before using in an ES5 environment
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/no-native.md
    'promise/no-native': OFF,

    // disallow nested `then()` or `catch()` statements
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/no-nesting.md
    'promise/no-nesting': WARN,

    // disallow using promises inside of callbacks
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/no-promise-in-callback.md
    'promise/no-promise-in-callback': ERROR,

    // disallow calling `cb()` inside of a `then()`
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/no-callback-in-promise.md
    'promise/no-callback-in-promise': ERROR,

    // disallow creating `new` promises outside of utility libs
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/avoid-new.md
    'promise/avoid-new': ERROR,

    // disallow calling `new` on a Promise static method
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/no-new-statics.md
    'promise/no-new-statics': ERROR,

    // disallow return statements in `finally()`
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/no-return-in-finally.md
    'promise/no-return-in-finally': ERROR,

    // enforce the proper number of arguments are passed to Promise functions
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/valid-params.md
    'promise/valid-params': ERROR,

    // prefer `await` to `then()`/`catch()`/`finally()` for reading Promise values
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/prefer-await-to-then.md
    'promise/prefer-await-to-then': ERROR,

    // prefer async/await to the callback pattern
    // https://github.com/xjamundx/eslint-plugin-promise/blob/development/docs/rules/prefer-await-to-callbacks.md
    'promise/prefer-await-to-callbacks': ERROR
  }
};
